<?php
namespace Planejamento\Logic\Cardapio;

use Geral\Util\DateUtil;
use Planejamento\Util\Parametros;
use Planejamento\Entities\Custpadr;

/**
 * Created by JetBrains PhpStorm.
 * User: jorgefonseca
 * Date: 19/01/13
 * Time: 12:21
 */
class Elaboracao
{

    private $nrorg;
    private $cdfilial;
    private $cdservfili;
    private $dtcardapio;

    public function __construct($nrorg, $cdfilial, $cdservfili, $dtcardapio) {
        $this->nrorg      = $nrorg;
        $this->cdfilial   = $cdfilial;
        $this->cdservfili = $cdservfili;
        $this->dtcardapio = $dtcardapio;
    }

    public function temConfiguracaoCardapioMes() {
        $confCardapioMes = \Planejamento\Entities\Cnfcames::getObjectByWhere(
            'NRORG = ? AND CDFILIAL = ? AND CDSERVFILI = ? AND DTREFECNFMES = ?',
            array($this->nrorg, $this->cdfilial, $this->cdservfili, $this->dtcardapio)
        );
        return (bool)$confCardapioMes;
    }

    public function criaConfiguracaoPadraoCardapio() {

        $conn = \Setforms2\Shared\Registry::getEntityManager();
        $conn->beginTransaction();

        $confsCard = \Planejamento\Entities\Confcard::getConfiguracoesCardapio(
            $this->nrorg,
            $this->cdfilial,
            $this->cdservfili
        );

        if (!$confsCard) {
            \Planejamento\Logic\Cardapio\Exception\Cardapio::servicoSemConfiguracao();
        }

         $dtrefecnfmes = \Geral\Util\DateUtil::getDataDeString($this->dtcardapio.' 00:00:00', \Geral\Util\DateUtil::FORMATO_BRASILEIRO_DATAHORA);

        /** @var $confCard \Planejamento\Entities\Confcard */
        foreach($confsCard as $confCard) {
            $cnfcames = new \Planejamento\Entities\Cnfcames();

            $cnfcames->setNrorg($this->nrorg);
            $cnfcames->setCdfilial($this->cdfilial);
            $cnfcames->setCdservfili($this->cdservfili);
            $cnfcames->setDtrefecnfmes($dtrefecnfmes);
            $cnfcames->setNrseqcnfmes($confCard->getNrseqcnfcard());
            $cnfcames->setCdtipoprat($confCard->getCdtipoprat());
            $cnfcames->setIdopccnfmes($confCard->getIdopccnfcard());
            $cnfcames->setIdimpcnfmes($confCard->getIdimpcnfcard());
            $cnfcames->setNrpagcnfmes(1);
            $cnfcames->setNrordcnfmes($confCard->getNrordcnfcard());
            $cnfcames->setDscompltpmes($confCard->getDscompltp());
            $cnfcames->setIdconcnfmes($confCard->getIdconcnfcard());
            $cnfcames->setIdtppratsegm($confCard->getIdtppratsegp());
            $cnfcames->setIdtppratterm($confCard->getIdtppratterp());
            $cnfcames->setIdtppratquam($confCard->getIdtppratquap());
            $cnfcames->setIdtppratquim($confCard->getIdtppratquip());
            $cnfcames->setIdtppratsexm($confCard->getIdtppratsexp());
            $cnfcames->setIdtppratsabm($confCard->getIdtppratsabp());
            $cnfcames->setIdtppratdomm($confCard->getIdtppratdomp());
            $cnfcames->setIdtppratferm($confCard->getIdtppratferp());

            $cnfcames->setDtinclusao(\Geral\Util\DateUtil::getDataAtual());            
            $cnfcames->setCdoperinclusao(\Geral\Util\Ambiente::getCdoperador());
            $cnfcames->setDtultatu(\Geral\Util\DateUtil::getDataAtual());
            $cnfcames->setNrorginclusao($this->nrorg);
            $cnfcames->setIdativo('S');

            $cnfcames->persist();
            $conn->flush();
        }

        $conn->commit();
    }
    
    
    public function verificaConsumoFixoPerCapita(){
        /** @var $dadosServico \Geral\Entities\Servico */
        $dadosServico = \Geral\Entities\Servico::getObject(
            array('nrorg' => $this->nrorg, 'cdfilial' => $this->cdfilial,
                'cdservfili' => $this->cdservfili)
        );
        
        if ($dadosServico->getIdconsservca() === 'S'){
            $dtFinal = DateUtil::getUltimoDiaDoMes(
                    DateUtil::getDataDeString($this->dtcardapio)
            )->format(DateUtil::FORMATO_DATA);

            /** @var $conservRepos \Planejamento\Repositories\Consserv */
            $conservRepos = \Planejamento\Entities\Consserv::getRepository();
            $consumo = $conservRepos->verificaConsumo(
                $this->nrorg, $this->cdfilial, $this->cdservfili, $this->dtcardapio, 
                $dtFinal, $this->dtcardapio
            );

            if (!$consumo) {
                \Planejamento\Logic\Cardapio\Exception\Cardapio::servSemConsFixoCapita();
            }
        }
        
        return true;
    }


    public function verificaCustoPadraoServico(){
        $verfCustpadr = Parametros::getInstancia($this->cdfilial)->getCustoPadraoCardapio();
        if ($verfCustpadr === 'S') {
            $data = DateUtil::getDataDeString($this->dtcardapio, DateUtil::FORMATO_BRASILEIRO, true);

            /** @var $custoPadrao Custpadr */
            $custoPadrao = Custpadr::getObject(
                array('cdfilial' => $this->cdfilial, 'cdservfili' => $this->cdservfili,
                    'dtrefcuspadr' => $data, 'nrorg' => $this->nrorg)
            );

            if (!$custoPadrao instanceof Custpadr)
                \Planejamento\Logic\Cardapio\Exception\Cardapio::custoPadrao();
        }

        return true;
    }


    public function verificaCardapio(){
        /** @var \Planejamento\Entities\Cardadia $cardapio */
        $cardapio = \Planejamento\Entities\Cardadia::getObjectByWhere(
            'NRORG = ? AND CDFILIAL = ? AND DTMESCARD = ? AND CDSERVFILI = ?',
            array($this->nrorg, $this->cdfilial, $this->dtcardapio, $this->cdservfili)
        );

        if (!($cardapio instanceof \Planejamento\Entities\Cardadia)) {
            \Planejamento\Logic\Cardapio\Exception\Cardapio::semCardapioPeriodo();
        }

    }

}
